@@ -1,9 +1,11 @@
 # -*- Mode: Python -*-
 
+from __future__ import absolute_import
+
 import unittest
 
 from gi.repository import GObject
-import testhelper
+from . import testhelper
 
 
 GUnknown = GObject.type_from_name("TestUnknown")
@@ -20,6 +22,8 @@ class MyUnknown(Unknown, testhelper.Interface):
     def do_iface_method(self):
         self.called = True
         Unknown.do_iface_method(self)
+
+
 GObject.type_register(MyUnknown)
 
 
@@ -32,6 +36,8 @@ class MyObject(GObject.GObject, testhelper.Interface):
 
     def do_iface_method(self):
         self.called = True
+
+
 GObject.type_register(MyObject)
 
 
